/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.UserTrade;
import org.springblade.modules.finance.vo.UserTradeVO;
import org.springblade.modules.finance.service.IUserTradeService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 用户提现表 控制器
 *
 * @author BladeX
 * @since 2022-04-02
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/usertrade")
@Api(value = "用户提现表", tags = "用户提现表接口")
public class UserTradeController extends BladeController {

	private final IUserTradeService userTradeService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入userTrade")
	public R<UserTrade> detail(UserTrade userTrade) {
		UserTrade detail = userTradeService.getOne(Condition.getQueryWrapper(userTrade));
		return R.data(detail);
	}

	/**
	 * 分页 用户提现表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入userTrade")
	public R<IPage<UserTrade>> list(UserTrade userTrade, Query query) {
		IPage<UserTrade> pages = userTradeService.page(Condition.getPage(query), Condition.getQueryWrapper(userTrade));
		return R.data(pages);
	}

	/**
	 * 自定义分页 用户提现表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入userTrade")
	public R<IPage<UserTradeVO>> page(UserTradeVO userTrade, Query query) {
		IPage<UserTradeVO> pages = userTradeService.selectUserTradePage(Condition.getPage(query), userTrade);
		return R.data(pages);
	}

	/**
	 * 新增 用户提现表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入userTrade")
	public R save(@Valid @RequestBody UserTrade userTrade) {
		return R.status(userTradeService.save(userTrade));
	}

	/**
	 * 修改 用户提现表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入userTrade")
	public R update(@Valid @RequestBody UserTrade userTrade) {
		return R.status(userTradeService.updateById(userTrade));
	}

	/**
	 * 新增或修改 用户提现表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入userTrade")
	public R submit(@Valid @RequestBody UserTrade userTrade) {
		return R.status(userTradeService.saveOrUpdate(userTrade));
	}

	
	/**
	 * 删除 用户提现表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(userTradeService.removeByIds(Func.toLongList(ids)));
	}

	
}
