/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * 寄售订单表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_order_consign")
@ApiModel(value = "OrderConsign对象", description = "寄售订单表")
public class OrderConsign implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 主键ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键ID")
	private Long id;

	/**
	 * 寄售用户ID
	 */
	@ApiModelProperty(value = "商品寄售ID")
	private Long consignId;

	/**
	 * 订单号
	 */
	@ApiModelProperty(value = "订单号")
	private String outTradeNo;

	/**
	 * 商品ID
	 */
	@ApiModelProperty(value = "商品ID")
	private Long goodsId;

	/**
	 * 商品名称
	 */
	@ApiModelProperty(value = "商品名称")
	private String goodsName;

	/**
	 * 总寄售价格
	 */
	@ApiModelProperty(value = "总寄售价格")
	private Double totalPrice;
	/**
	 * 数量
	 */
	@ApiModelProperty(value = "数量")
	private Integer totalNum;

	/**
	 * 寄售天数
	 */
	@ApiModelProperty(value = "寄售天数")
	private Integer consignDays;
	/**
	 * 寄售用户ID
	 */
	@ApiModelProperty(value = "寄售用户ID")
	private Long consignUserId;
	/**
	 * 支付用户ID
	 */
	@ApiModelProperty(value = "支付用户ID")
	private Long payUserId;

	/**
	 * 寄售类型
	 */
	@ApiModelProperty(value = "寄售类型:0无，1提货，2寄售")
	private Integer consignType;

	/**
	 * 寄售价格
	 */
	@ApiModelProperty(value = "寄售价格")
	private Double consignPrice;
	/**
	 * 创建时间
	 */
	@ApiModelProperty(value = "创建时间")
	private Date createTime;

	/**
	 * 是否确认
	 */
	@ApiModelProperty(value = "是否确认")
	private Integer isConfirm;

	/**
	 * 确认时间
	 */
	@ApiModelProperty(value = "确认时间")
	private Date confirmTime;

	/**
	 * 说明
	 */
	@ApiModelProperty(value = "信息说明体")
	private String body;

	@TableField(exist = false)
	@ApiModelProperty(value = "商品编号")
	private String productNo;

	@TableField(exist = false)
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	@ApiModelProperty(value = "开始时间")
	private Date startTime;

	@TableField(exist = false)
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	@ApiModelProperty(value = "结束时间")
	private Date endTime;
}
