/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.shopping.entity.GoodsAttributes;
import org.springblade.modules.shopping.vo.GoodsAttributesVO;
import org.springblade.modules.shopping.service.IGoodsAttributesService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 商品属性表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/goodsattributes")
@Api(value = "商品属性表", tags = "商品属性表接口")
public class GoodsAttributesController extends BladeController {

	private final IGoodsAttributesService goodsAttributesService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入goodsAttributes")
	public R<GoodsAttributes> detail(GoodsAttributes goodsAttributes) {
		GoodsAttributes detail = goodsAttributesService.getOne(Condition.getQueryWrapper(goodsAttributes));
		return R.data(detail);
	}

	/**
	 * 分页 商品属性表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入goodsAttributes")
	public R<IPage<GoodsAttributes>> list(GoodsAttributes goodsAttributes, Query query) {
		IPage<GoodsAttributes> pages = goodsAttributesService.page(Condition.getPage(query), Condition.getQueryWrapper(goodsAttributes));
		return R.data(pages);
	}

	/**
	 * 自定义分页 商品属性表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入goodsAttributes")
	public R<IPage<GoodsAttributesVO>> page(GoodsAttributesVO goodsAttributes, Query query) {
		IPage<GoodsAttributesVO> pages = goodsAttributesService.selectGoodsAttributesPage(Condition.getPage(query), goodsAttributes);
		return R.data(pages);
	}

	/**
	 * 新增 商品属性表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入goodsAttributes")
	public R save(@Valid @RequestBody GoodsAttributes goodsAttributes) {
		return R.status(goodsAttributesService.save(goodsAttributes));
	}

	/**
	 * 修改 商品属性表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入goodsAttributes")
	public R update(@Valid @RequestBody GoodsAttributes goodsAttributes) {
		return R.status(goodsAttributesService.updateById(goodsAttributes));
	}

	/**
	 * 新增或修改 商品属性表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入goodsAttributes")
	public R submit(@Valid @RequestBody GoodsAttributes goodsAttributes) {
		return R.status(goodsAttributesService.saveOrUpdate(goodsAttributes));
	}

	
	/**
	 * 删除 商品属性表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(goodsAttributesService.removeByIds(Func.toLongList(ids)));
	}

	
}
