/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 商品规格值表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_spec_items")
@ApiModel(value = "SpecItems对象", description = "商品规格值表")
public class SpecItems extends Model<SpecItems> {

	private static final long serialVersionUID = 1L;

	/**
	 * 主键ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "spec_id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键ID")
	private Long specId;
	/**
	 * 分类ID
	 */
	@ApiModelProperty(value = "分类ID")
	private Long specCatId;
	/**
	 * 商品ID
	 */
	@ApiModelProperty(value = "商品ID")
	private Long goodsId;
	/**
	 * 项名称
	 */
	@ApiModelProperty(value = "项名称")
	private String itemName;
	/**
	 * 规格描述
	 */
	@ApiModelProperty(value = "规格描述")
	private String itemDesc;
	/**
	 * 规格图片
	 */
	@ApiModelProperty(value = "规格图片")
	private String itemImg;
	/**
	 * 删除标识   0正常  1逻辑删除
	 */
	@TableLogic
	@ApiModelProperty(value = "删除标识   0正常  1逻辑删除")
	private Integer isDeleted;
	/**
	 * 创建时间
	 */
	@ApiModelProperty(value = "创建时间")
	private Date createTime;


}
