/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.vo;

import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.annotations.ApiModelProperty;
import org.springblade.modules.shopping.entity.Goods;
import lombok.Data;
import lombok.EqualsAndHashCode;
import io.swagger.annotations.ApiModel;
import org.springblade.modules.shopping.entity.GoodsAttributes;
import org.springblade.modules.shopping.entity.GoodsSpecs;

import java.util.List;

/**
 * 商品表视图实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "GoodsVO对象", description = "商品表")
public class GoodsVO extends Goods {

	private static final long serialVersionUID = 1L;

	@ApiModelProperty(value = "是否上架")
	private String isSaleDisplayName;

	@ApiModelProperty(value = "是否推荐")
	private String isRecomDisplayName;

	@ApiModelProperty(value = "是否热销")
	private String isHotDisplayName;

	@ApiModelProperty(value = "是否新品")
	private String isNewDisplayName;

	@ApiModelProperty(value = "是否酒票购买")
	private String isTicketDisplayName;

	@ApiModelProperty(value = "商品类型")
	private String goodsTypeDisplayName;

	@ApiModelProperty(value = "是否包邮")
	private String isFreeShippingDisplayName;

	@ApiModelProperty(value = "是否有规格")
	private String isSpecDisplayName;

	@JsonIgnore
	@ApiModelProperty(value = "商品状态，-1:违规 0:未审核 1:已审核")
	private String goodsStatusDisplayName;

	@ApiModelProperty(value = "品牌")
	private String brandName;

	@ApiModelProperty(value = "商品参数")
	private List<GoodsAttributesVO> goodsAttributes;

	@ApiModelProperty(value = "商品规格项值")
	private List<SpecItemsVO> specItems;

}
