/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.wrapper;

import org.springblade.common.cache.DictBizCache;
import org.springblade.common.cache.DictCache;
import org.springblade.common.cache.SysCache;
import org.springblade.common.enums.DictBizEnum;
import org.springblade.common.enums.DictEnum;
import org.springblade.core.mp.support.BaseEntityWrapper;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.core.tool.utils.SpringUtil;
import org.springblade.modules.shopping.entity.Brands;
import org.springblade.modules.shopping.entity.Goods;
import org.springblade.modules.shopping.service.IBrandsService;
import org.springblade.modules.shopping.vo.GoodsVO;
import org.springblade.modules.system.entity.Tenant;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.vo.UserVO;

import java.util.List;
import java.util.Objects;

/**
 * 包装类,返回视图层所需的字段
 *
 * @author Chill
 */
public class GoodsWrapper extends BaseEntityWrapper<Goods, GoodsVO> {

	private static IBrandsService brandsService;

	static {
		brandsService = SpringUtil.getBean(IBrandsService.class);
	}

	public static GoodsWrapper build() {
		return new GoodsWrapper();
	}

	@Override
	public GoodsVO entityVO(Goods entity) {
		GoodsVO vo = Objects.requireNonNull(BeanUtil.copy(entity, GoodsVO.class));
		vo.setIsSaleDisplayName(DictCache.getValue(DictEnum.YES_NO, entity.getIsSale()));
		vo.setIsRecomDisplayName(DictCache.getValue(DictEnum.YES_NO, entity.getIsRecom()));
		vo.setIsHotDisplayName(DictCache.getValue(DictEnum.YES_NO, entity.getIsHot()));
		vo.setIsNewDisplayName(DictCache.getValue(DictEnum.YES_NO, entity.getIsNew()));
		vo.setIsFreeShippingDisplayName(DictCache.getValue(DictEnum.YES_NO, entity.getIsFreeShipping()));
		vo.setIsSpecDisplayName(DictCache.getValue(DictEnum.YES_NO, entity.getIsSpec()));
		vo.setIsTicketDisplayName(DictCache.getValue(DictEnum.YES_NO, entity.getIsTicket()));
		vo.setGoodsStatusDisplayName(DictBizCache.getValue(DictBizEnum.EXAM_STATUE, entity.getGoodsStatus()));
		Brands brands = brandsService.getById(entity.getBrandId());
		if(brands != null){
			vo.setBrandName(brands.getBrandName());
		}
		//商品类型-待定
		return vo;
	}
}
